__init__ — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# __init__

Poscar.__init__(filename: str = 'POSCAR', verbose: bool = False)

  The file is not automatically loaded, you need to run self.parse()

  Parameters:

    - filename (str,) – POSCAR-like file

    - verbose (bool,) – verbosity level, for debugging. Default: False

  Variables:

    - self.verbose

    - self.filename

    - self.poscar (str str with the full POSCAR file)

    - self.cpos (np.nadarray, Cartesian coordinates)

    - self.dpos (np.ndarray, direct coordinates)

    - self.lat (np.ndarray (3x3), the lattice)

    - self.typeSp (list, aame of atomic species, ordered)

    - self.numberSp (np.ndarray, number of atoms per specie)

    - self.Ntotal (int, total number of atoms in system)

    - self.elm (list, element of each atoms one-by-one.)

    - self.selective (bool, Selective dynamics?)

    - self.selectFlags (None or nd.array(str), flags of selective dynamics)

    - self.flags (dict, list of flags. Not used here just for convenience)

    - self.volume (float, the box product of the lattice)